Documentation
¶
Overview ¶
This package has the automatically generated clientset.
Index ¶
- type Clientset
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) EventingV1alpha1() eventingv1alpha1.EventingV1alpha1Interface
- func (c *Clientset) FlowsV1alpha1() flowsv1alpha1.FlowsV1alpha1Interface
- func (c *Clientset) MessagingV1alpha1() messagingv1alpha1.MessagingV1alpha1Interface
- func (c *Clientset) SourcesV1alpha1() sourcesv1alpha1.SourcesV1alpha1Interface
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
type Clientset struct {
*discovery.DiscoveryClient
// contains filtered or unexported fields
}
Clientset contains the clients for groups. Each group has exactly one version included in a Clientset.
func NewForConfig ¶
NewForConfig creates a new Clientset for the given config.
func NewForConfigOrDie ¶
NewForConfigOrDie creates a new Clientset for the given config and panics if there is an error in the config.
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
Discovery retrieves the DiscoveryClient
func (*Clientset) EventingV1alpha1 ¶
func (c *Clientset) EventingV1alpha1() eventingv1alpha1.EventingV1alpha1Interface
EventingV1alpha1 retrieves the EventingV1alpha1Client
func (*Clientset) FlowsV1alpha1 ¶ added in v0.11.0
func (c *Clientset) FlowsV1alpha1() flowsv1alpha1.FlowsV1alpha1Interface
FlowsV1alpha1 retrieves the FlowsV1alpha1Client
func (*Clientset) MessagingV1alpha1 ¶ added in v0.7.0
func (c *Clientset) MessagingV1alpha1() messagingv1alpha1.MessagingV1alpha1Interface
MessagingV1alpha1 retrieves the MessagingV1alpha1Client
func (*Clientset) SourcesV1alpha1 ¶ added in v0.6.0
func (c *Clientset) SourcesV1alpha1() sourcesv1alpha1.SourcesV1alpha1Interface
SourcesV1alpha1 retrieves the SourcesV1alpha1Client
type Interface ¶
type Interface interface {
Discovery() discovery.DiscoveryInterface
EventingV1alpha1() eventingv1alpha1.EventingV1alpha1Interface
FlowsV1alpha1() flowsv1alpha1.FlowsV1alpha1Interface
MessagingV1alpha1() messagingv1alpha1.MessagingV1alpha1Interface
SourcesV1alpha1() sourcesv1alpha1.SourcesV1alpha1Interface
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
typed
|
|
|
eventing/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
eventing/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
flows/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
flows/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
messaging/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
messaging/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
sources/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
sources/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
Click to show internal directories.
Click to hide internal directories.