Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FlowsV1alpha1Client ¶
type FlowsV1alpha1Client struct {
// contains filtered or unexported fields
}
FlowsV1alpha1Client is used to interact with features provided by the flows.knative.dev group.
func New ¶
func New(c rest.Interface) *FlowsV1alpha1Client
New creates a new FlowsV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*FlowsV1alpha1Client, error)
NewForConfig creates a new FlowsV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *FlowsV1alpha1Client
NewForConfigOrDie creates a new FlowsV1alpha1Client for the given config and panics if there is an error in the config.
func (*FlowsV1alpha1Client) Parallels ¶
func (c *FlowsV1alpha1Client) Parallels(namespace string) ParallelInterface
func (*FlowsV1alpha1Client) RESTClient ¶
func (c *FlowsV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*FlowsV1alpha1Client) Sequences ¶
func (c *FlowsV1alpha1Client) Sequences(namespace string) SequenceInterface
type FlowsV1alpha1Interface ¶
type FlowsV1alpha1Interface interface {
RESTClient() rest.Interface
ParallelsGetter
SequencesGetter
}
type ParallelExpansion ¶
type ParallelExpansion interface{}
type ParallelInterface ¶
type ParallelInterface interface {
Create(*v1alpha1.Parallel) (*v1alpha1.Parallel, error)
Update(*v1alpha1.Parallel) (*v1alpha1.Parallel, error)
UpdateStatus(*v1alpha1.Parallel) (*v1alpha1.Parallel, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Parallel, error)
List(opts v1.ListOptions) (*v1alpha1.ParallelList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Parallel, err error)
ParallelExpansion
}
ParallelInterface has methods to work with Parallel resources.
type ParallelsGetter ¶
type ParallelsGetter interface {
Parallels(namespace string) ParallelInterface
}
ParallelsGetter has a method to return a ParallelInterface. A group's client should implement this interface.
type SequenceExpansion ¶
type SequenceExpansion interface{}
type SequenceInterface ¶
type SequenceInterface interface {
Create(*v1alpha1.Sequence) (*v1alpha1.Sequence, error)
Update(*v1alpha1.Sequence) (*v1alpha1.Sequence, error)
UpdateStatus(*v1alpha1.Sequence) (*v1alpha1.Sequence, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Sequence, error)
List(opts v1.ListOptions) (*v1alpha1.SequenceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Sequence, err error)
SequenceExpansion
}
SequenceInterface has methods to work with Sequence resources.
type SequencesGetter ¶
type SequencesGetter interface {
Sequences(namespace string) SequenceInterface
}
SequencesGetter has a method to return a SequenceInterface. A group's client should implement this interface.