Documentation
¶
Index ¶
Constants ¶
const ( // ReconcilerName is the name of the reconciler ReconcilerName = "Namespace" // TODO: Namespace is not a very good name for this controller. )
Variables ¶
This section is empty.
Functions ¶
func NewController ¶
NewController initializes the controller and is called by the generated code Registers event handlers to enqueue events
Types ¶
type Reconciler ¶
type Reconciler struct {
*reconciler.Base
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.